@@ -7,7 +7,7 @@
 *
 *	This file part of:	SExtractor
 *
-*	Copyright:		(C) 1993-2015 Emmanuel Bertin -- IAP/CNRS/UPMC
+*	Copyright:		(C) 1993-2023 CFHT/IAP/CNRS/SorbonneU
 *
 *	License:		GNU General Public License
 *
@@ -22,7 +22,7 @@
 *	You should have received a copy of the GNU General Public License
 *	along with SExtractor. If not, see <http://www.gnu.org/licenses/>.
 *
-*	Last modified:		21/01/2015
+*	Last modified:		07/03/2023
 *
 *%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
@@ -43,7 +43,9 @@
 #include	"assoc.h"
 #include	"back.h"
 #include	"check.h"
+#ifdef USE_MODEL 
 #include	"fft.h"
+#endif
 #include	"field.h"
 #include	"filter.h"
 #include	"growth.h"
@@ -56,14 +58,20 @@
 #include	"xml.h"
 
 static int		selectext(char *filename);
+
 time_t			thetimet, thetimet2;
 #ifdef USE_MODEL
 extern profitstruct	*theprofit,*thedprofit, *thepprofit,*theqprofit;
 #else
-profitstruct	*theprofit,*thedprofit, *thepprofit,*theqprofit;
+profitstruct		*theprofit,*thedprofit, *thepprofit,*theqprofit;
 #endif
 extern char		profname[][32];
-double			dtime;
+extern float		ctg[37], stg[37];
+
+sexcatstruct		thecat;
+picstruct		thefield1,thefield2, thewfield1,thewfield2;
+char			gstr[MAXCHAR];
+
 
 /******************************** makeit *************************************/
 /*
@@ -80,6 +88,7 @@ void	makeit()
    patternstruct	*pattern;
    static time_t        thetime1, thetime2;
    struct tm		*tm;
+   double		dtime;
    unsigned int		modeltype;
    int			nflag[MAXFLAG], nparam2[2],
 			i, nok, ntab, next, ntabmax, forcextflag,
@@ -273,7 +282,7 @@ void	makeit()
       {
 /*---- Check for the next valid image extension */
       if ((imatab->naxis < 2)
-	|| !strncmp(imatab->xtension, "BINTABLE", 8)
+    || !(imatab->isTileCompressed || strncmp(imatab->xtension, "BINTABLE", 8))
 	|| !strncmp(imatab->xtension, "ASCTABLE", 8))
         continue;
       next++;
@@ -312,10 +321,9 @@ void	makeit()
     {
 /*--  Check for the next valid image extension */
     if (!forcextflag && ((imatab->naxis < 2)
-	|| !strncmp(imatab->xtension, "BINTABLE", 8)
+    || !(imatab->isTileCompressed || strncmp(imatab->xtension, "BINTABLE", 8))
 	|| !strncmp(imatab->xtension, "ASCTABLE", 8)))
       continue;
-
     nok++;
 
 /*-- Initial time measurement*/
@@ -699,8 +707,8 @@ INPUT	Filename character string.
 OUTPUT	Extension number, or RETURN_ERROR if nos extension specified.
 NOTES	The bracket and its extension number are removed from the filename if
 	found.
-AUTHOR  E. Bertin (IAP)
-VERSION 08/10/2007
+AUTHOR  E. Bertin (CFHT/IAP)
+VERSION 07/03/2023
  ***/
 static int	selectext(char *filename)
   {
@@ -713,6 +721,7 @@ static int	selectext(char *filename)
     if ((bracr=strrchr(bracl+1, ']')))
       *bracr = '\0';
     next = strtol(bracl+1, NULL, 0);
+
     return next;
     }
 
@@ -728,9 +737,9 @@ INPUT	a character string,
 OUTPUT	RETURN_OK if everything went fine, RETURN_ERROR otherwise.
 NOTES	-.
 AUTHOR	E. Bertin (IAP)
-VERSION	14/07/2006
+VERSION	23/09/2020
  ***/
-void	write_error(char *msg1, char *msg2)
+void	write_error(const char *msg1, const char *msg2)
   {
    char			error[MAXCHAR];
 
