@@ -7,7 +7,7 @@
 *
 *	This file part of:	SExtractor
 *
-*	Copyright:		(C) 1998-2015 Emmanuel Bertin -- IAP/CNRS/UPMC
+*	Copyright:		(C) 1998-2020 IAP/CNRS/SorbonneU
 *
 *	License:		GNU General Public License
 *
@@ -22,7 +22,7 @@
 *	You should have received a copy of the GNU General Public License
 *	along with SExtractor. If not, see <http://www.gnu.org/licenses/>.
 *
-*	Last modified:		15/12/2015
+*	Last modified:		15/07/2020
 *
 *%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
@@ -50,7 +50,10 @@
 
 
 extern keystruct	objkey[];
-extern objstruct	outobj;
+
+psfstruct	*psf,*thedpsf,*thepsf;
+psfitstruct	*thepsfit,*thedpsfit;
+PIXTYPE		*checkmask;
 
 /********************************* psf_init **********************************/
 /*
